@@ -868,6 +868,8 @@ Socket::address::address(Socket &s, const char *host, const char *svc)
 	assert(host != NULL && *host != 0);
 	assert(svc != NULL && *svc != 0);
 
+	list = NULL;
+
 #ifdef	_MSWINDOWS_
 	Socket::init();
 #endif
@@ -941,7 +943,6 @@ void Socket::address::set(const char *host, unsigned port, int family)
 		hint.ai_flags |= AI_V4MAPPED;
 #endif
 
-	list = NULL;
 	getaddrinfo(host, svc, &hint, &list);
 }
 
@@ -999,7 +1000,6 @@ proc:
 		hint.ai_flags |= AI_V4MAPPED;
 #endif
 
-	list = NULL;
 	getaddrinfo(host, svc, &hint, &list);
 }
 
@@ -2103,7 +2103,7 @@ struct addrinfo *Socket::gethint(socket_t so, struct addrinfo *hint)
 
 	struct sockaddr_storage st;
 	struct sockaddr *sa = (struct sockaddr *)&st;
-	socklen_t slen;
+	socklen_t slen = sizeof(st);
 
 	memset(hint, 0, sizeof(struct addrinfo));
 	memset(sa, 0, sizeof(st));
@@ -2265,6 +2265,37 @@ exit:
 	return rtn;
 }
 
+unsigned Socket::keyhost(struct sockaddr *addr, unsigned keysize)
+{
+	assert(addr != NULL);
+	assert(keysize > 0);
+
+	unsigned key = 0;
+	caddr_t cp = NULL;
+	unsigned len;
+switch(addr->sa_family) {
+#ifdef	AF_INET6
+	case AF_INET6:
+		cp = (caddr_t)(&((struct sockaddr_in6 *)(addr))->sin6_addr);
+		len = 16;
+		break;
+#endif
+	case AF_INET:
+		cp = (caddr_t)(&((struct sockaddr_in *)(addr))->sin_addr);
+		len = 4;
+		break;
+	default:
+		return 0;
+	}
+	while(len--) {
+		key = key << 1;
+		key ^= cp[len];
+	}
+	return key % keysize;	
+}
+
+
+
 unsigned Socket::keyindex(struct sockaddr *addr, unsigned keysize)
 {
 	assert(addr != NULL);
@@ -2622,4 +2653,34 @@ FILE *Socket::open(socket_t so, bool mode)
 	return fdopen(dup(so), "r");
 }
 
+bool Socket::isNull(const char *str)
+{
+	assert(str != NULL);
+
+	while(*str && strchr("0:.", *str) != NULL)
+		++str;
+	
+	if(*str)
+		return false;
+
+	return true;
+}
+
+bool Socket::isNumeric(const char *str)
+{
+	assert(str != NULL);
+
+	// if raw ipv6, then we can just exit, no chance to confuse with names
+	if(strchr(str, ':'))
+		return true;
+
+	while(*str && strchr("0123456789.", *str) != NULL)
+		++str;
+	
+	if(*str)
+		return false;
+
+	return true;
+}
+
 #endif 
